By using an example for urge to smoke in the McNeish and Hamaker (2020), this data set is a simulated subset. It consists of 10 repetitions on regular time scales for 20 different individuals. For response variable, urge to Smoke is on a standardized scale average 0 and the standard deviation 1.
1 | data("ml2")
|
A data frame with 200 observations on the following 6 variables.
urgestandardized urge to smoke
urge1previous urge to smoke
depstandardized depression
dep1previous depression
idindividual indicator
timetime indicator
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.